@@ -102,13 +102,13 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cognito
-import aws_cdk.aws_elasticloadbalancingv2
-import aws_cdk.core
+import aws_cdk.aws_cognito as _aws_cdk_aws_cognito_371ee794
+import aws_cdk.aws_elasticloadbalancingv2 as _aws_cdk_aws_elasticloadbalancingv2_e93c784f
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
 class AuthenticateCognitoAction(
-    aws_cdk.aws_elasticloadbalancingv2.ListenerAction,
+    _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ListenerAction,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-elasticloadbalancingv2-actions.AuthenticateCognitoAction",
 ):
@@ -185,15 +185,15 @@ class AuthenticateCognitoAction(
     def __init__(
         self,
         *,
-        next: aws_cdk.aws_elasticloadbalancingv2.ListenerAction,
-        user_pool: aws_cdk.aws_cognito.IUserPool,
-        user_pool_client: aws_cdk.aws_cognito.IUserPoolClient,
-        user_pool_domain: aws_cdk.aws_cognito.IUserPoolDomain,
+        next: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ListenerAction,
+        user_pool: _aws_cdk_aws_cognito_371ee794.IUserPool,
+        user_pool_client: _aws_cdk_aws_cognito_371ee794.IUserPoolClient,
+        user_pool_domain: _aws_cdk_aws_cognito_371ee794.IUserPoolDomain,
         authentication_request_extra_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        on_unauthenticated_request: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.UnauthenticatedAction] = None,
+        on_unauthenticated_request: typing.Optional[_aws_cdk_aws_elasticloadbalancingv2_e93c784f.UnauthenticatedAction] = None,
         scope: typing.Optional[builtins.str] = None,
         session_cookie_name: typing.Optional[builtins.str] = None,
-        session_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        session_timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
     ) -> None:
         '''Authenticate using an identity provide (IdP) that is compliant with OpenID Connect (OIDC).
 
@@ -241,15 +241,15 @@ class AuthenticateCognitoActionProps:
     def __init__(
         self,
         *,
-        next: aws_cdk.aws_elasticloadbalancingv2.ListenerAction,
-        user_pool: aws_cdk.aws_cognito.IUserPool,
-        user_pool_client: aws_cdk.aws_cognito.IUserPoolClient,
-        user_pool_domain: aws_cdk.aws_cognito.IUserPoolDomain,
+        next: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ListenerAction,
+        user_pool: _aws_cdk_aws_cognito_371ee794.IUserPool,
+        user_pool_client: _aws_cdk_aws_cognito_371ee794.IUserPoolClient,
+        user_pool_domain: _aws_cdk_aws_cognito_371ee794.IUserPoolDomain,
         authentication_request_extra_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        on_unauthenticated_request: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.UnauthenticatedAction] = None,
+        on_unauthenticated_request: typing.Optional[_aws_cdk_aws_elasticloadbalancingv2_e93c784f.UnauthenticatedAction] = None,
         scope: typing.Optional[builtins.str] = None,
         session_cookie_name: typing.Optional[builtins.str] = None,
-        session_timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        session_timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
     ) -> None:
         '''Properties for AuthenticateCognitoAction.
 
@@ -331,20 +331,7 @@ class AuthenticateCognitoActionProps:
             app.synth()
         '''
         if __debug__:
-            def stub(
-                *,
-                next: aws_cdk.aws_elasticloadbalancingv2.ListenerAction,
-                user_pool: aws_cdk.aws_cognito.IUserPool,
-                user_pool_client: aws_cdk.aws_cognito.IUserPoolClient,
-                user_pool_domain: aws_cdk.aws_cognito.IUserPoolDomain,
-                authentication_request_extra_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                on_unauthenticated_request: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.UnauthenticatedAction] = None,
-                scope: typing.Optional[builtins.str] = None,
-                session_cookie_name: typing.Optional[builtins.str] = None,
-                session_timeout: typing.Optional[aws_cdk.core.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__fbce001587e055b7c08d47f6e7ff3bf6e3f598eb42912711ad6a7de73ce43fcc)
             check_type(argname="argument next", value=next, expected_type=type_hints["next"])
             check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
             check_type(argname="argument user_pool_client", value=user_pool_client, expected_type=type_hints["user_pool_client"])
@@ -354,7 +341,7 @@ class AuthenticateCognitoActionProps:
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument session_cookie_name", value=session_cookie_name, expected_type=type_hints["session_cookie_name"])
             check_type(argname="argument session_timeout", value=session_timeout, expected_type=type_hints["session_timeout"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "next": next,
             "user_pool": user_pool,
             "user_pool_client": user_pool_client,
@@ -372,7 +359,7 @@ class AuthenticateCognitoActionProps:
             self._values["session_timeout"] = session_timeout
 
     @builtins.property
-    def next(self) -> aws_cdk.aws_elasticloadbalancingv2.ListenerAction:
+    def next(self) -> _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ListenerAction:
         '''What action to execute next.
 
         Multiple actions form a linked chain; the chain must always terminate in a
@@ -380,28 +367,28 @@ class AuthenticateCognitoActionProps:
         '''
         result = self._values.get("next")
         assert result is not None, "Required property 'next' is missing"
-        return typing.cast(aws_cdk.aws_elasticloadbalancingv2.ListenerAction, result)
+        return typing.cast(_aws_cdk_aws_elasticloadbalancingv2_e93c784f.ListenerAction, result)
 
     @builtins.property
-    def user_pool(self) -> aws_cdk.aws_cognito.IUserPool:
+    def user_pool(self) -> _aws_cdk_aws_cognito_371ee794.IUserPool:
         '''The Amazon Cognito user pool.'''
         result = self._values.get("user_pool")
         assert result is not None, "Required property 'user_pool' is missing"
-        return typing.cast(aws_cdk.aws_cognito.IUserPool, result)
+        return typing.cast(_aws_cdk_aws_cognito_371ee794.IUserPool, result)
 
     @builtins.property
-    def user_pool_client(self) -> aws_cdk.aws_cognito.IUserPoolClient:
+    def user_pool_client(self) -> _aws_cdk_aws_cognito_371ee794.IUserPoolClient:
         '''The Amazon Cognito user pool client.'''
         result = self._values.get("user_pool_client")
         assert result is not None, "Required property 'user_pool_client' is missing"
-        return typing.cast(aws_cdk.aws_cognito.IUserPoolClient, result)
+        return typing.cast(_aws_cdk_aws_cognito_371ee794.IUserPoolClient, result)
 
     @builtins.property
-    def user_pool_domain(self) -> aws_cdk.aws_cognito.IUserPoolDomain:
+    def user_pool_domain(self) -> _aws_cdk_aws_cognito_371ee794.IUserPoolDomain:
         '''The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.'''
         result = self._values.get("user_pool_domain")
         assert result is not None, "Required property 'user_pool_domain' is missing"
-        return typing.cast(aws_cdk.aws_cognito.IUserPoolDomain, result)
+        return typing.cast(_aws_cdk_aws_cognito_371ee794.IUserPoolDomain, result)
 
     @builtins.property
     def authentication_request_extra_params(
@@ -417,13 +404,13 @@ class AuthenticateCognitoActionProps:
     @builtins.property
     def on_unauthenticated_request(
         self,
-    ) -> typing.Optional[aws_cdk.aws_elasticloadbalancingv2.UnauthenticatedAction]:
+    ) -> typing.Optional[_aws_cdk_aws_elasticloadbalancingv2_e93c784f.UnauthenticatedAction]:
         '''The behavior if the user is not authenticated.
 
         :default: UnauthenticatedAction.AUTHENTICATE
         '''
         result = self._values.get("on_unauthenticated_request")
-        return typing.cast(typing.Optional[aws_cdk.aws_elasticloadbalancingv2.UnauthenticatedAction], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_elasticloadbalancingv2_e93c784f.UnauthenticatedAction], result)
 
     @builtins.property
     def scope(self) -> typing.Optional[builtins.str]:
@@ -446,13 +433,13 @@ class AuthenticateCognitoActionProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def session_timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
+    def session_timeout(self) -> typing.Optional[_aws_cdk_core_f4b25747.Duration]:
         '''The maximum duration of the authentication session.
 
         :default: Duration.days(7)
         '''
         result = self._values.get("session_timeout")
-        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+        return typing.cast(typing.Optional[_aws_cdk_core_f4b25747.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -472,3 +459,18 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__fbce001587e055b7c08d47f6e7ff3bf6e3f598eb42912711ad6a7de73ce43fcc(
+    *,
+    next: _aws_cdk_aws_elasticloadbalancingv2_e93c784f.ListenerAction,
+    user_pool: _aws_cdk_aws_cognito_371ee794.IUserPool,
+    user_pool_client: _aws_cdk_aws_cognito_371ee794.IUserPoolClient,
+    user_pool_domain: _aws_cdk_aws_cognito_371ee794.IUserPoolDomain,
+    authentication_request_extra_params: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    on_unauthenticated_request: typing.Optional[_aws_cdk_aws_elasticloadbalancingv2_e93c784f.UnauthenticatedAction] = None,
+    scope: typing.Optional[builtins.str] = None,
+    session_cookie_name: typing.Optional[builtins.str] = None,
+    session_timeout: typing.Optional[_aws_cdk_core_f4b25747.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
